@@ -2,6 +2,7 @@ import sys
 import logging
 import colorlog
 from bs4 import BeautifulSoup
+from firexkit.result import ChainInterruptedException
 
 console_stdout = None
 console_stderr = None
@@ -42,6 +43,11 @@ class RetryFilter(logging.Filter):
         return 'Retry in' not in record.getMessage()
 
 
+class ChainInterruptedExceptionFilter(logging.Filter):
+    def filter(self, record):
+        return ChainInterruptedException.__name__ not in record.getMessage()
+
+
 def setup_console_logging(module=None,
                           stdout_logging_level=logging.INFO,
                           console_logging_formatter='%(green)s[%(asctime)s]%(reset)s[%(hostname)s] %(log_color)s%(message)s',
@@ -50,7 +56,6 @@ def setup_console_logging(module=None,
                           module_logger_logging_level=None):
     global console_stdout
     global console_stderr
-
     formatter = FireXColoredConsoleFormatter(fmt=console_logging_formatter,
                                              datefmt=console_datefmt,
                                              log_colors={'DEBUG': 'cyan',
@@ -60,6 +65,8 @@ def setup_console_logging(module=None,
                                                          'CRITICAL': 'red,bg_white'})
 
     if module == "__main__":
+        from firexapp.engine.logging import add_hostname_to_log_records
+        add_hostname_to_log_records()
         # For program entry point, use root logger
         module_logger = logging.getLogger()
         # noinspection PyUnresolvedReferences
@@ -97,6 +104,7 @@ def setup_console_logging(module=None,
     console_stderr.setLevel(stderr_logging_level)
     console_stderr.setFormatter(formatter)
     console_stderr.addFilter(RetryFilter())
+    console_stderr.addFilter(ChainInterruptedExceptionFilter())
 
     module_logger.addHandler(console_stdout)
     module_logger.addHandler(console_stderr)
