@@ -14,16 +14,19 @@ from shutil import copyfile
 from contextlib import contextmanager
 
 from celery.exceptions import NotRegistered
+from firexapp.discovery import get_firex_dependant_package_versions, PkgVersionInfo
 from firexapp.engine.logging import add_hostname_to_log_records
 
 from firexkit.result import wait_on_async_results, disable_async_result, ChainRevokedException, \
     mark_queues_ready, get_results, get_task_name_from_result, ChainRevokedPreRunException, \
     monkey_patch_async_result_to_track_instances, is_async_result_monkey_patched_to_track, disable_all_async_results
+import firexkit
+import firexapp
 from firexkit.chain import InjectArgs, verify_chain_arguments, InvalidChainArgsException
 from firexapp.fileregistry import FileRegistry
 from firexapp.submit.uid import Uid
 from firexapp.submit.arguments import InputConverter, ChainArgException, get_chain_args, find_unused_arguments
-from firexapp.submit.tracking_service import get_tracking_services, get_service_name
+from firexapp.submit.tracking_service import get_tracking_services, get_service_name, get_tracking_services_versions
 from firexapp.plugins import plugin_support_parser
 from firexapp.submit.console import setup_console_logging
 from firexapp.application import import_microservices, get_app_tasks, get_app_task
@@ -110,7 +113,6 @@ class SubmitBaseApp:
         del self.submit_parser
 
     def init_file_logging(self):
-        os.umask(0)
         if self.submission_tmp_file:
             submission_log_handler = logging.FileHandler(filename=self.submission_tmp_file)
             submission_log_handler.setFormatter(logging.Formatter(fmt=self.SUBMISSION_LOGGING_FORMATTER,
@@ -130,16 +132,13 @@ class SubmitBaseApp:
 
     @staticmethod
     def log_firex_pkgs_versions():
-        import pkg_resources
-        pkgs = []
-        for package in pkg_resources.WorkingSet():
-            if package.project_name == 'firexkit':
-                pkgs.append(str(package))
-            for r in package.requires():
-                if r.project_name in ['firexkit', 'firexapp']:
-                    pkgs.append(str(package))
-        pkgs = [f'\t - {p}' for p in pkgs]
-        logger.debug('FireX Packages:\n' + '\n'.join(pkgs))
+        pkg_version_info = [PkgVersionInfo(pkg='firexkit', version=firexkit.__version__),
+                            PkgVersionInfo(pkg='firexapp', version=firexapp.__version__)] \
+                           + get_tracking_services_versions() \
+                           + get_firex_dependant_package_versions()
+
+        pkg_version_info_str = [f'\t - {p_info}' for p_info in pkg_version_info]
+        logger.debug('FireX Packages:\n' + '\n'.join(pkg_version_info_str))
 
     def create_submit_parser(self, sub_parser):
         submit_parser = sub_parser.add_parser("submit",
@@ -456,11 +455,11 @@ class SubmitBaseApp:
                 # requested_service_names being None means "load all installed".
                 is_requested = requested_service_names is None or service_name in requested_service_names
 
-                detail = ''
+                detail = f'v{service.get_version()}'
                 if not is_requested:
-                    detail = '(not requested via install_config)'
+                    detail += ' (not requested via install_config)'
                 elif is_cli_disabled:
-                    detail = '(CLI disabled)'
+                    detail += ' (CLI disabled)'
                 else:
                     detail += ' '
                 logger.debug(f"\t{service_name} {detail}")
